# Authors of Vivarium Core

The maintainers of the Vivarium project (known as the Vivarium Authors)
are:

* Eran Agmon  (@eagmon)
* Ryan Spangler (@prismofeverything)
* Chris Skalnik (@U8NWXD)

Vivarium Core was built by:

* Members of the [Covert Lab](https://covert.stanford.edu) at
  [Stanford University](https://stanford.edu):

  * [Eran Agmon](https://eagmon.github.io): `eagmon AT stanford DOT edu`
  * Ryan Spangler: `ryan.spangler AT gmail DOT com`
  * [Chris Skalnik](https://u8nwxd.github.io)
  * Jerry Morrison: `j.erry.morrison AT gmail DOT com`
  * Mattheus Wolff: `mbwolff AT stanford DOT edu`
  * Sean Cheah: `seancheah AT ucla DOT edu`
  * Michael Yang (@Robotato): `michaelyang42 AT gmail DOT com`

* William Poole
